Mooring System Design Methodology
=================================

For details of the code implementation, please see
:doc:`Mooring System Design API <api_MooringSystemDesign>`.

Overview
--------

The mooring system design module in ORBIT is based on previous modeling
efforts undertaken by NREL, [#maness2017]_. The technical documentation for
this tool can be found `here <https://www.nrel.gov/docs/fy17osti/66874.pdf>_`.

References
----------

.. [#maness2017] Michael Maness, Benjamin Maples, Aaron Smith,
    NREL Offshore Balance-of-System Model, 2017
